==> lxqt-config_1.1.0.orig.tar.xz: lxqt-config-1.1.0/lxqt-config-appearance/translations/lxqt-config-appearance_ko.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="ko">
<context>
    <name>ColorLabel</name>
    <message>
        <location filename="../colorLabel.cpp" line="37"/>
        <source>Click to change color.</source>
        <translation>색상을 변경하려면 클릭하십시오.</translation>
    </message>
    <message>
        <location filename="../colorLabel.cpp" line="61"/>
        <source>Select Color</source>
        <translation>색상 선택</translation>
    </message>
</context>
<context>
    <name>ConfigOtherToolKits</name>
    <message>
        <location filename="../configothertoolkits.cpp" line="170"/>
        <source>GTK themes</source>
        <translation>GTK 테마</translation>
    </message>
    <message>
        <location filename="../configothertoolkits.cpp" line="171"/>
        <source>&lt;p&gt;&apos;%1&apos; has been overwritten.&lt;/p&gt;&lt;p&gt;You can find a copy of your old settings in &apos;%2&apos;&lt;/p&gt;</source>
        <translation>&lt;p&gt;&apos;%1&apos; 덮어 써졌습니다.&lt;/p&gt;&lt;p&gt;&apos;%2&apos;에서 이전 설정의 복사본을 찾으실 수 있습니다&lt;/p&gt;</translation>
    </message>
    <message>
        <location filename="../configothertoolkits.cpp" line="235"/>
        <source>Error</source>
        <translation>오류</translation>
    </message>
    <message>
        <location filename="../configothertoolkits.cpp" line="235"/>
        <source>Error: gsettings cannot be run</source>
        <translation>오류: gsettings를 실행할 수 없습니다</translation>
    </message>
</context>
<context>
    <name>FontsConfig</name>
    <message>
        <location filename="../fontsconfig.ui" line="23"/>
        <source>Font</source>
        <translation>글꼴</translation>
    </message>
    <message>
        <location filename="../fontsconfig.ui" line="30"/>
        <source>Default font for user interface</source>
        <translation>사용자 환경을 위한 기본 글꼴</translation>
    </message>
    <message>
        <location filename="../fontsconfig.ui" line="36"/>
        <source>Font name:</source>
        <translation>글꼴 이름:</translation>
    </message>
    <message>
        <location filename="../fontsconfig.ui" line="46"/>
        <source>Style:</source>
        <translation>스타일:</translation>
    </message>
    <message>
        <location filename="../fontsconfig.ui" line="53"/>
        <source>Point size:</source>
        <translation>글꼴 크기:</translation>
    </message>
    <message>
        <location filename="../fontsconfig.ui" line="68"/>
        <source>Normal</source>
        <translation>기본</translation>
    </message>
    <message>
        <location filename="../fontsconfig.ui" line="73"/>
        <source>Bold</source>
        <translation>굵게</translation>
    </message>
    <message>
        <location filename="../fontsconfig.ui" line="78"/>
        <source>Italic</source>
        <translation>기울게</translation>
    </message>
    <message>
        <location filename="../fontsconfig.ui" line="83"/>
        <source>Bold Italic</source>
        <translation>굵고 기울게</translation>
    </message>
    <message>
        <location filename="../fontsconfig.ui" line="94"/>
        <source>The following settings only affect newly started applications</source>
        <translation>다음 설정은 새로 시작된 응용 프로그램에만 영향을 줍니다</translation>
    </message>
    <message>
        <location filename="../fontsconfig.ui" line="100"/>
        <source>Use antialias fonts</source>
        <translation>글꼴에 안티앨리어싱 사용하기</translation>
    </message>
    <message>
        <location filename="../fontsconfig.ui" line="107"/>
        <source>Font hinting style:</source>
        <translation>글꼴 힌팅 스타일:</translation>
    </message>
    <message>
        <location filename="../fontsconfig.ui" line="118"/>
        <location filename="../fontsconfig.ui" line="183"/>
        <source>None</source>
        <translation>사용 안 함</translation>
    </message>
    <message>
        <location filename="../fontsconfig.ui" line="123"/>
        <source>Slight</source>
        <translation>엷게</translation>
    </message>
    <message>
        <location filename="../fontsconfig.ui" line="128"/>
        <source>Medium</source>
        <translation>중간</translation>
    </message>
    <message>
        <location filename="../fontsconfig.ui" line="133"/>
        <source>Full</source>
        <translation>전부</translation>
    </message>
    <message>
        <location filename="../fontsconfig.ui" line="141"/>
        <source>Font hinting</source>
        <translation>글꼴 힌팅</translation>
    </message>
    <message>
        <location filename="../fontsconfig.ui" line="148"/>
        <source>Resolution (DPI):</source>
        <translation>해상도 (DPI):</translation>
    </message>
    <message>
        <location filename="../fontsconfig.ui" line="155"/>
        <source>Autohint</source>
        <translation>자동 힌팅</translation>
    </message>
    <message>
        <location filename="../fontsconfig.ui" line="172"/>
        <source>Subpixel antialiasing:</source>
        <translation>서브픽셀 안티앨리어싱:</translation>
    </message>
    <message>
        <location filename="../fontsconfig.ui" line="188"/>
        <source>RGB</source>
        <translation>RGB</translation>
    </message>
    <message>
        <location filename="../fontsconfig.ui" line="193"/>
        <source>BGR</source>
        <translation>BGR</translation>
    </message>
    <message>
        <location filename="../fontsconfig.ui" line="198"/>
        <source>VRGB</source>
        <translation>VRGB</translation>
    </message>
    <message>
        <location filename="../fontsconfig.ui" line="203"/>
        <source>VBGR</source>
        <translation>VBGR</translation>
    </message>
</context>
<context>
    <name>GTKConfig</name>
    <message>
        <location filename="../gtkconfig.ui" line="44"/>
        <source>GTK Style</source>
        <translation>GTK 스타일</translation>
    </message>
    <message>
        <location filename="../gtkconfig.ui" line="63"/>
        <source>Set GTK themes (GTK configuration files will be overwritten!)</source>
        <translation>GTK 테마 지정 (GTK 구성 파일을 덮어씁니다!)</translation>
    </message>
    <message>
        <location filename="../gtkconfig.ui" line="83"/>
        <source>GTK 3 Theme</source>
        <translation>GTK 3 테마</translation>
    </message>
    <message>
        <location filename="../gtkconfig.ui" line="93"/>
        <source>GTK 2 Theme</source>
        <translation>GTK 2 테마</translation>
    </message>
    <message>
        <location filename="../gtkconfig.ui" line="103"/>
        <source>To attempt uniform theming, either select similar style/theme (if available) across all lists, or select &apos;gtk2&apos; Qt style (if available) to mimic GTK themes.

Make sure &apos;xsettingsd&apos; is installed to help GTK applications apply themes on the fly.</source>
        <translation>균일한 테마를 시도하려면 모든 목록에서 유사한 스타일/테마(사용 가능한 경우)를 선택하거나 &apos;gtk2&apos; Qt 스타일(사용 가능한 경우)을 선택하여 GTK 테마를 모방합니다.

GTK 응용 프로그램이 테마를 즉석에서 적용할 수 있도록 &apos;xsettingsd&apos;가 설치되어 있는지 확인하십시오.</translation>
    </message>
</context>
<context>
    <name>IconThemeConfig</name>
    <message>
        <location filename="../iconthemeconfig.ui" line="14"/>
        <source>LXQt Appearance Configuration</source>
        <translation>LXQt 모양새 구성</translation>
    </message>
    <message>
        <location filename="../iconthemeconfig.ui" line="26"/>
        <source>Icons Theme</source>
        <translation>아이콘 테마</translation>
    </message>
    <message>
        <location filename="../iconthemeconfig.ui" line="87"/>
        <source>The KDE extension of XDG icon themes -&gt; FollowsColorScheme</source>
        <translation>XDG 아이콘 테마의 KDE 확장 -&gt; FollowsColorScheme</translation>
    </message>
    <message>
        <location filename="../iconthemeconfig.ui" line="90"/>
        <source>Colorize icons based on widget style (palette)</source>
        <translation>위젯 스타일(팔레트) 기반 아이콘 색상 지정</translation>
    </message>
</context>
<context>
    <name>LXQtThemeConfig</name>
    <message>
        <location filename="../lxqtthemeconfig.ui" line="23"/>
        <source>LXQt Theme</source>
        <translation>LXQt 테마</translation>
    </message>
    <message>
        <location filename="../lxqtthemeconfig.ui" line="57"/>
        <source>Override user-defined wallpaper</source>
        <translation>사용자가 설정한 배경화면 덮어쓰기</translation>
    </message>
</context>
<context>
    <name>PalettesDialog</name>
    <message>
        <location filename="../palettes.ui" line="14"/>
        <location filename="../palettes.ui" line="20"/>
        <source>Palettes</source>
        <translation>팔레트</translation>
    </message>
    <message>
        <location filename="../palettes.ui" line="33"/>
        <source>Filter...</source>
        <translation>필터...</translation>
    </message>
    <message>
        <location filename="../palettes.ui" line="43"/>
        <source>&amp;Remove</source>
        <translation>제거(&amp;R)</translation>
    </message>
</context>
<context>
    <name>QObject</name>
    <message>
        <location filename="../main.cpp" line="62"/>
        <source>LXQt Appearance Configuration</source>
        <translation>LXQt 모양새 구성</translation>
    </message>
    <message>
        <location filename="../main.cpp" line="75"/>
        <source>Widget Style</source>
        <translation>위젯 스타일</translation>
    </message>
    <message>
        <location filename="../main.cpp" line="84"/>
        <source>Icons Theme</source>
        <translation>아이콘 테마</translation>
    </message>
    <message>
        <location filename="../main.cpp" line="93"/>
        <source>LXQt Theme</source>
        <translation>LXQt 테마</translation>
    </message>
    <message>
        <location filename="../main.cpp" line="101"/>
        <source>Font</source>
        <translation>글꼴</translation>
    </message>
    <message>
        <location filename="../main.cpp" line="111"/>
        <source>Cursor</source>
        <translation>커서</translation>
    </message>
    <message>
        <location filename="../main.cpp" line="118"/>
        <source>GTK Style</source>
        <translation>GTK 스타일</translation>
    </message>
</context>
<context>
    <name>StyleConfig</name>
    <message>
        <location filename="../styleconfig.ui" line="33"/>
        <source>Widget Style</source>
        <translation>위젯 스타일</translation>
    </message>
    <message>
        <location filename="../styleconfig.ui" line="63"/>
        <source>Qt Palette</source>
        <translation>Qt 팔레트</translation>
    </message>
    <message>
        <location filename="../styleconfig.ui" line="77"/>
        <source>Some Qt styles may ignore these colors.</source>
        <translation>일부 Qt 스타일은 이러한 색상을 무시할 수 있습니다.</translation>
    </message>
    <message>
        <location filename="../styleconfig.ui" line="102"/>
        <source>Window:</source>
        <translation>창:</translation>
    </message>
    <message>
        <location filename="../styleconfig.ui" line="112"/>
        <source>View:</source>
        <translation>보기:</translation>
    </message>
    <message>
        <location filename="../styleconfig.ui" line="122"/>
        <source>Selection:</source>
        <translation>선택:</translation>
    </message>
    <message>
        <location filename="../styleconfig.ui" line="132"/>
        <source>Link:</source>
        <translation>링크:</translation>
    </message>
    <message>
        <location filename="../styleconfig.ui" line="152"/>
        <source>Window Text:</source>
        <translation>창 텍스트:</translation>
    </message>
    <message>
        <location filename="../styleconfig.ui" line="162"/>
        <source>View Text:</source>
        <translation>보기 텍스트:</translation>
    </message>
    <message>
        <location filename="../styleconfig.ui" line="172"/>
        <source>Selected Text:</source>
        <translation>선택한 텍스트:</translation>
    </message>
    <message>
        <location filename="../styleconfig.ui" line="182"/>
        <source>Visited Link:</source>
        <translation>방문한 링크:</translation>
    </message>
    <message>
        <location filename="../styleconfig.ui" line="214"/>
        <source>&amp;Save Palette</source>
        <translation>팔레트 저장(&amp;S)</translation>
    </message>
    <message>
        <location filename="../styleconfig.ui" line="221"/>
        <source>&amp;Load Palette</source>
        <translation>팔레트 불러오기(&amp;L)</translation>
    </message>
    <message>
        <location filename="../styleconfig.ui" line="241"/>
        <source>&amp;Default Palette</source>
        <translation>기본 팔레트(&amp;D)</translation>
    </message>
    <message>
        <location filename="../styleconfig.ui" line="256"/>
        <source>Toolbar button style:</source>
        <translation>툴바 버튼 스타일:</translation>
    </message>
    <message>
        <location filename="../styleconfig.ui" line="264"/>
        <source>Only display the icon</source>
        <translation>아이콘만 보이기</translation>
    </message>
    <message>
        <location filename="../styleconfig.ui" line="269"/>
        <source>Only display the text</source>
        <translation>텍스트만 보이기</translation>
    </message>
    <message>
        <location filename="../styleconfig.ui" line="274"/>
        <source>The text appears beside the icon</source>
        <translation>아이콘 옆에 텍스트가 나타납니다</translation>
    </message>
    <message>
        <location filename="../styleconfig.ui" line="279"/>
        <source>The text appears under the icon</source>
        <translation>아이콘 아래에 텍스트가 나타납니다</translation>
    </message>
    <message>
        <location filename="../styleconfig.ui" line="284"/>
        <source>Default</source>
        <translation>기본</translation>
    </message>
    <message>
        <location filename="../styleconfig.ui" line="292"/>
        <source>Activate item on single click</source>
        <translation>한 번 클릭으로 실행하기</translation>
    </message>
    <message>
        <location filename="../styleconfig.ui" line="51"/>
        <source>Qt Style</source>
        <translation>Qt 스타일</translation>
    </message>
    <message>
        <location filename="../styleconfig.cpp" line="245"/>
        <location filename="../styleconfig.cpp" line="255"/>
        <source>Save Palette</source>
        <translation>팔레트 저장</translation>
    </message>
    <message>
        <location filename="../styleconfig.cpp" line="245"/>
        <source>Palette name:</source>
        <translation>팔레트 이름:</translation>
    </message>
    <message>
        <location filename="../styleconfig.cpp" line="256"/>
        <source>A palette with the same name exists.
Do you want to replace it?</source>
        <translation>같은 이름의 팔레트가 있습니다.
교체하시겠습니까?</translation>
    </message>
    <message>
        <location filename="../styleconfig.cpp" line="393"/>
        <source>Remove Palettes</source>
        <translation>팔레트 제거</translation>
    </message>
    <message>
        <location filename="../styleconfig.cpp" line="394"/>
        <source>Do you really want to remove selected palette(s)?
Root palettes will remain intact if existing.</source>
        <translation>선택한 팔레트를 정말로 제거하시겠습니까?
루트 팔레트는 존재하는 경우 그대로 유지됩니다.</translation>
    </message>
</context>
</TS>

==> lxqt-config_1.3.0.orig.tar.xz: lxqt-config-1.3.0/lxqt-config-appearance/translations/lxqt-config-appearance_ko.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="ko">
<context>
    <name>ColorLabel</name>
    <message>
        <location filename="../colorLabel.cpp" line="37"/>
        <source>Click to change color.</source>
        <translation>색상을 변경하려면 클릭하십시오.</translation>
    </message>
    <message>
        <location filename="../colorLabel.cpp" line="61"/>
        <source>Select Color</source>
        <translation>색상 선택</translation>
    </message>
</context>
<context>
    <name>ConfigOtherToolKits</name>
    <message>
        <location filename="../configothertoolkits.cpp" line="170"/>
        <source>GTK themes</source>
        <translation>GTK 테마</translation>
    </message>
    <message>
        <location filename="../configothertoolkits.cpp" line="171"/>
        <source>&lt;p&gt;&apos;%1&apos; has been overwritten.&lt;/p&gt;&lt;p&gt;You can find a copy of your old settings in &apos;%2&apos;&lt;/p&gt;</source>
        <translation>&lt;p&gt;&apos;%1&apos; 덮어 써졌습니다.&lt;/p&gt;&lt;p&gt;&apos;%2&apos;에서 이전 설정의 복사본을 찾으실 수 있습니다&lt;/p&gt;</translation>
    </message>
    <message>
        <location filename="../configothertoolkits.cpp" line="235"/>
        <source>Error</source>
        <translation>오류</translation>
    </message>
    <message>
        <location filename="../configothertoolkits.cpp" line="235"/>
        <source>Error: gsettings cannot be run</source>
        <translation>오류: gsettings를 실행할 수 없습니다</translation>
    </message>
</context>
<context>
    <name>FontsConfig</name>
    <message>
        <location filename="../fontsconfig.ui" line="23"/>
        <source>Font</source>
        <translation>글꼴</translation>
    </message>
    <message>
        <location filename="../fontsconfig.ui" line="30"/>
        <source>Default font for user interface</source>
        <translation>사용자 환경을 위한 기본 글꼴</translation>
    </message>
    <message>
        <location filename="../fontsconfig.ui" line="36"/>
        <source>Font name:</source>
        <translation>글꼴 이름:</translation>
    </message>
    <message>
        <location filename="../fontsconfig.ui" line="46"/>
        <source>Style:</source>
        <translation>스타일:</translation>
    </message>
    <message>
        <location filename="../fontsconfig.ui" line="53"/>
        <source>Point size:</source>
        <translation>글꼴 크기:</translation>
    </message>
    <message>
        <location filename="../fontsconfig.ui" line="68"/>
        <source>Normal</source>
        <translation>기본</translation>
    </message>
    <message>
        <location filename="../fontsconfig.ui" line="73"/>
        <source>Bold</source>
        <translation>굵게</translation>
    </message>
    <message>
        <location filename="../fontsconfig.ui" line="78"/>
        <source>Italic</source>
        <translation>기울게</translation>
    </message>
    <message>
        <location filename="../fontsconfig.ui" line="83"/>
        <source>Bold Italic</source>
        <translation>굵고 기울게</translation>
    </message>
    <message>
        <location filename="../fontsconfig.ui" line="94"/>
        <source>The following settings only affect newly started applications</source>
        <translation>다음 설정은 새로 시작된 응용 프로그램에만 영향을 줍니다</translation>
    </message>
    <message>
        <location filename="../fontsconfig.ui" line="100"/>
        <source>Use antialias fonts</source>
        <translation>글꼴에 안티앨리어싱 사용하기</translation>
    </message>
    <message>
        <location filename="../fontsconfig.ui" line="107"/>
        <source>Font hinting style:</source>
        <translation>글꼴 힌팅 스타일:</translation>
    </message>
    <message>
        <location filename="../fontsconfig.ui" line="118"/>
        <location filename="../fontsconfig.ui" line="183"/>
        <source>None</source>
        <translation>사용 안 함</translation>
    </message>
    <message>
        <location filename="../fontsconfig.ui" line="123"/>
        <source>Slight</source>
        <translation>엷게</translation>
    </message>
    <message>
        <location filename="../fontsconfig.ui" line="128"/>
        <source>Medium</source>
        <translation>중간</translation>
    </message>
    <message>
        <location filename="../fontsconfig.ui" line="133"/>
        <source>Full</source>
        <translation>전부</translation>
    </message>
    <message>
        <location filename="../fontsconfig.ui" line="141"/>
        <source>Font hinting</source>
        <translation>글꼴 힌팅</translation>
    </message>
    <message>
        <location filename="../fontsconfig.ui" line="148"/>
        <source>Resolution (DPI):</source>
        <translation>해상도 (DPI):</translation>
    </message>
    <message>
        <location filename="../fontsconfig.ui" line="155"/>
        <source>Autohint</source>
        <translation>자동 힌팅</translation>
    </message>
    <message>
        <location filename="../fontsconfig.ui" line="172"/>
        <source>Subpixel antialiasing:</source>
        <translation>서브픽셀 안티앨리어싱:</translation>
    </message>
    <message>
        <location filename="../fontsconfig.ui" line="188"/>
        <source>RGB</source>
        <translation>RGB</translation>
    </message>
    <message>
        <location filename="../fontsconfig.ui" line="193"/>
        <source>BGR</source>
        <translation>BGR</translation>
    </message>
    <message>
        <location filename="../fontsconfig.ui" line="198"/>
        <source>VRGB</source>
        <translation>VRGB</translation>
    </message>
    <message>
        <location filename="../fontsconfig.ui" line="203"/>
        <source>VBGR</source>
        <translation>VBGR</translation>
    </message>
</context>
<context>
    <name>GTKConfig</name>
    <message>
        <location filename="../gtkconfig.ui" line="44"/>
        <source>GTK Style</source>
        <translation>GTK 스타일</translation>
    </message>
    <message>
        <location filename="../gtkconfig.ui" line="63"/>
        <source>Set GTK themes (GTK configuration files will be overwritten!)</source>
        <translation>GTK 테마 지정 (GTK 구성 파일을 덮어씁니다!)</translation>
    </message>
    <message>
        <location filename="../gtkconfig.ui" line="83"/>
        <source>GTK 3 Theme</source>
        <translation>GTK 3 테마</translation>
    </message>
    <message>
        <location filename="../gtkconfig.ui" line="93"/>
        <source>GTK 2 Theme</source>
        <translation>GTK 2 테마</translation>
    </message>
    <message>
        <location filename="../gtkconfig.ui" line="103"/>
        <source>To attempt uniform theming, either select similar style/theme (if available) across all lists, or select &apos;gtk2&apos; Qt style (if available) to mimic GTK themes.

Make sure &apos;xsettingsd&apos; is installed to help GTK applications apply themes on the fly.</source>
        <translation>균일한 테마를 시도하려면 모든 목록에서 유사한 스타일/테마(사용 가능한 경우)를 선택하거나 &apos;gtk2&apos; Qt 스타일(사용 가능한 경우)을 선택하여 GTK 테마를 모방합니다.

GTK 응용 프로그램이 테마를 즉석에서 적용할 수 있도록 &apos;xsettingsd&apos;가 설치되어 있는지 확인하십시오.</translation>
    </message>
</context>
<context>
    <name>IconThemeConfig</name>
    <message>
        <location filename="../iconthemeconfig.ui" line="14"/>
        <source>LXQt Appearance Configuration</source>
        <translation>LXQt 모양새 구성</translation>
    </message>
    <message>
        <location filename="../iconthemeconfig.ui" line="26"/>
        <source>Icons Theme</source>
        <translation>아이콘 테마</translation>
    </message>
    <message>
        <location filename="../iconthemeconfig.ui" line="87"/>
        <source>The KDE extension of XDG icon themes -&gt; FollowsColorScheme</source>
        <translation>XDG 아이콘 테마의 KDE 확장 -&gt; FollowsColorScheme</translation>
    </message>
    <message>
        <location filename="../iconthemeconfig.ui" line="90"/>
        <source>Colorize icons based on widget style (palette)</source>
        <translation>위젯 스타일(팔레트) 기반 아이콘 색상 지정</translation>
    </message>
</context>
<context>
    <name>LXQtThemeConfig</name>
    <message>
        <location filename="../lxqtthemeconfig.ui" line="23"/>
        <source>LXQt Theme</source>
        <translation>LXQt 테마</translation>
    </message>
    <message>
        <location filename="../lxqtthemeconfig.ui" line="57"/>
        <source>Use wallpaper provided by theme</source>
        <translation>테마에서 제공하는 배경화면 사용하기</translation>
    </message>
    <message>
        <location filename="../lxqtthemeconfig.cpp" line="94"/>
        <source>(User Theme)</source>
        <translation>(사용자 테마)</translation>
    </message>
    <message>
        <location filename="../lxqtthemeconfig.cpp" line="182"/>
        <source>Open theme folder</source>
        <translation>테마 폴더 열기</translation>
    </message>
</context>
<context>
    <name>PalettesDialog</name>
    <message>
        <location filename="../palettes.ui" line="14"/>
        <location filename="../palettes.ui" line="20"/>
        <source>Palettes</source>
        <translation>팔레트</translation>
    </message>
    <message>
        <location filename="../palettes.ui" line="33"/>
        <source>Filter...</source>
        <translation>필터...</translation>
    </message>
    <message>
        <location filename="../palettes.ui" line="43"/>
        <source>&amp;Remove</source>
        <translation>제거(&amp;R)</translation>
    </message>
</context>
<context>
    <name>QObject</name>
    <message>
        <location filename="../main.cpp" line="62"/>
        <source>LXQt Appearance Configuration</source>
        <translation>LXQt 모양새 구성</translation>
    </message>
    <message>
        <location filename="../main.cpp" line="75"/>
        <source>Widget Style</source>
        <translation>위젯 스타일</translation>
    </message>
    <message>
        <location filename="../main.cpp" line="84"/>
        <source>Icons Theme</source>
        <translation>아이콘 테마</translation>
    </message>
    <message>
        <location filename="../main.cpp" line="93"/>
        <source>LXQt Theme</source>
        <translation>LXQt 테마</translation>
    </message>
    <message>
        <location filename="../main.cpp" line="101"/>
        <source>Font</source>
        <translation>글꼴</translation>
    </message>
    <message>
        <location filename="../main.cpp" line="111"/>
        <source>Cursor</source>
        <translation>커서</translation>
    </message>
    <message>
        <location filename="../main.cpp" line="118"/>
        <source>GTK Style</source>
        <translation>GTK 스타일</translation>
    </message>
</context>
<context>
    <name>StyleConfig</name>
    <message>
        <location filename="../styleconfig.ui" line="33"/>
        <source>Widget Style</source>
        <translation>위젯 스타일</translation>
    </message>
    <message>
        <location filename="../styleconfig.ui" line="63"/>
        <source>Qt Palette</source>
        <translation>Qt 팔레트</translation>
    </message>
    <message>
        <location filename="../styleconfig.ui" line="77"/>
        <source>Some Qt styles may ignore these colors.</source>
        <translation>일부 Qt 스타일은 이러한 색상을 무시할 수 있습니다.</translation>
    </message>
    <message>
        <location filename="../styleconfig.ui" line="102"/>
        <source>Window:</source>
        <translation>창:</translation>
    </message>
    <message>
        <location filename="../styleconfig.ui" line="112"/>
        <source>View:</source>
        <translation>보기:</translation>
    </message>
    <message>
        <location filename="../styleconfig.ui" line="122"/>
        <source>Selection:</source>
        <translation>선택:</translation>
    </message>
    <message>
        <location filename="../styleconfig.ui" line="132"/>
        <source>Link:</source>
        <translation>링크:</translation>
    </message>
    <message>
        <location filename="../styleconfig.ui" line="152"/>
        <source>Window Text:</source>
        <translation>창 텍스트:</translation>
    </message>
    <message>
        <location filename="../styleconfig.ui" line="162"/>
        <source>View Text:</source>
        <translation>보기 텍스트:</translation>
    </message>
    <message>
        <location filename="../styleconfig.ui" line="172"/>
        <source>Selected Text:</source>
        <translation>선택한 텍스트:</translation>
    </message>
    <message>
        <location filename="../styleconfig.ui" line="182"/>
        <source>Visited Link:</source>
        <translation>방문한 링크:</translation>
    </message>
    <message>
        <location filename="../styleconfig.ui" line="214"/>
        <source>&amp;Save Palette</source>
        <translation>팔레트 저장(&amp;S)</translation>
    </message>
    <message>
        <location filename="../styleconfig.ui" line="221"/>
        <source>&amp;Load Palette</source>
        <translation>팔레트 불러오기(&amp;L)</translation>
    </message>
    <message>
        <location filename="../styleconfig.ui" line="241"/>
        <source>&amp;Default Palette</source>
        <translation>기본 팔레트(&amp;D)</translation>
    </message>
    <message>
        <location filename="../styleconfig.ui" line="256"/>
        <source>Toolbar button style:</source>
        <translation>툴바 버튼 스타일:</translation>
    </message>
    <message>
        <location filename="../styleconfig.ui" line="264"/>
        <source>Only display the icon</source>
        <translation>아이콘만 보이기</translation>
    </message>
    <message>
        <location filename="../styleconfig.ui" line="269"/>
        <source>Only display the text</source>
        <translation>텍스트만 보이기</translation>
    </message>
    <message>
        <location filename="../styleconfig.ui" line="274"/>
        <source>The text appears beside the icon</source>
        <translation>아이콘 옆에 텍스트가 나타납니다</translation>
    </message>
    <message>
        <location filename="../styleconfig.ui" line="279"/>
        <source>The text appears under the icon</source>
        <translation>아이콘 아래에 텍스트가 나타납니다</translation>
    </message>
    <message>
        <location filename="../styleconfig.ui" line="284"/>
        <source>Default</source>
        <translation>기본</translation>
    </message>
    <message>
        <location filename="../styleconfig.ui" line="292"/>
        <source>Activate item on single click</source>
        <translation>한 번 클릭으로 실행하기</translation>
    </message>
    <message>
        <location filename="../styleconfig.ui" line="51"/>
        <source>Qt Style</source>
        <translation>Qt 스타일</translation>
    </message>
    <message>
        <location filename="../styleconfig.cpp" line="245"/>
        <location filename="../styleconfig.cpp" line="255"/>
        <source>Save Palette</source>
        <translation>팔레트 저장</translation>
    </message>
    <message>
        <location filename="../styleconfig.cpp" line="245"/>
        <source>Palette name:</source>
        <translation>팔레트 이름:</translation>
    </message>
    <message>
        <location filename="../styleconfig.cpp" line="256"/>
        <source>A palette with the same name exists.
Do you want to replace it?</source>
        <translation>같은 이름의 팔레트가 있습니다.
교체하시겠습니까?</translation>
    </message>
    <message>
        <location filename="../styleconfig.cpp" line="393"/>
        <source>Remove Palettes</source>
        <translation>팔레트 제거</translation>
    </message>
    <message>
        <location filename="../styleconfig.cpp" line="394"/>
        <source>Do you really want to remove selected palette(s)?
Root palettes will remain intact if existing.</source>
        <translation>선택한 팔레트를 정말로 제거하시겠습니까?
루트 팔레트는 존재하는 경우 그대로 유지됩니다.</translation>
    </message>
</context>
</TS>
